@@ -1,16 +1,15 @@
-use crate::app::{Add, Run};
-use crate::config;
-use crate::db::DatabaseFile;
-use crate::util;
+use std::path::Path;
 
 use anyhow::{bail, Result};
 
-use std::path::Path;
+use crate::app::{Add, Run};
+use crate::db::DatabaseFile;
+use crate::{config, util};
 
 impl Run for Add {
     fn run(&self) -> Result<()> {
-        // These characters can't be printed cleanly to a single line, so they
-        // can cause confusion when writing to fzf / stdout.
+        // These characters can't be printed cleanly to a single line, so they can cause confusion
+        // when writing to fzf / stdout.
         const EXCLUDE_CHARS: &[char] = &['\n', '\r'];
 
         let data_dir = config::data_dir()?;
@@ -21,16 +20,11 @@ impl Run for Add {
         let mut db = DatabaseFile::new(data_dir);
         let mut db = db.open()?;
 
-        for path in self.paths.iter() {
-            let path = if config::resolve_symlinks() {
-                util::canonicalize(path)
-            } else {
-                util::resolve_path(path)
-            }?;
+        for path in &self.paths {
+            let path = if config::resolve_symlinks() { util::canonicalize } else { util::resolve_path }(path)?;
             let path = util::path_to_str(&path)?;
 
-            // Ignore path if it contains unsupported characters, or if it's in
-            // the exclude list.
+            // Ignore path if it contains unsupported characters, or if it's in the exclude list.
             if path.contains(EXCLUDE_CHARS) || exclude_dirs.iter().any(|glob| glob.matches(path)) {
                 continue;
             }
